=== modified file 'drizzled/plugin/storage_engine.h'
--- drizzled/plugin/storage_engine.h	2009-03-26 00:21:07 +0000
+++ drizzled/plugin/storage_engine.h	2009-03-26 00:22:17 +0000
@@ -98,20 +98,20 @@
       session->ha_data[xxx_engine.slot]
 
    slot number is initialized by MySQL after xxx_init() is called.
-   */
-   uint32_t slot;
-   std::bitset<HTON_BIT_SIZE> flags; /* global handler flags */
-   /*
-     to store per-savepoint data storage engine is provided with an area
-     of a requested size (0 is ok here).
-     savepoint_offset must be initialized statically to the size of
-     the needed memory to store per-savepoint information.
-     After xxx_init it is changed to be an offset to savepoint storage
-     area and need not be used by storage engine.
-     see binlog_engine and binlog_savepoint_set/rollback for an example.
-   */
-   uint32_t savepoint_offset;
-   uint32_t license; /* Flag for Engine License */
+  */
+  uint32_t slot;
+  std::bitset<HTON_BIT_SIZE> flags; /* global handler flags */
+  /*
+    to store per-savepoint data storage engine is provided with an area
+    of a requested size (0 is ok here).
+    savepoint_offset must be initialized statically to the size of
+    the needed memory to store per-savepoint information.
+    After xxx_init it is changed to be an offset to savepoint storage
+    area and need not be used by storage engine.
+    see binlog_engine and binlog_savepoint_set/rollback for an example.
+  */
+  uint32_t savepoint_offset;
+  uint32_t license; /* Flag for Engine License */
 
   StorageEngine(const std::string &name_arg, bool support_2pc= false)
     : name(name_arg), two_phase_commit(support_2pc), savepoint_offset(0)  {}
@@ -123,87 +123,86 @@
   }
 
 
-
-   bool is_enabled() const
-   {
-     return (state == SHOW_OPTION_YES);
-   }
-
-   std::string get_name() { return name; }
-
-   /*
-     StorageEngine methods:
-
-     close_connection is only called if
-     session->ha_data[xxx_engine.slot] is non-zero, so even if you don't need
-     this storage area - set it to something, so that MySQL would know
-     this storage engine was accessed in this connection
-   */
-   virtual int close_connection(Session  *)
-   {
-     return 0;
-   }
-   /*
-     The void * points to an uninitialized storage area of requested size
-     (see savepoint_offset description)
-   */
-   virtual int savepoint_set(Session *, void *)
-   {
-     return 0;
-   }
-
-   /*
-     The void * points to a storage area, that was earlier passed
-     to the savepoint_set call
-   */
-   virtual int savepoint_rollback(Session *, void *)
-   {
-     return 0;
-   }
-
-   virtual int savepoint_release(Session *, void *)
-   {
-     return 0;
-   }
-
-   /*
-     'all' is true if it's a real commit, that makes persistent changes
-     'all' is false if it's not in fact a commit but an end of the
-     statement that is part of the transaction.
-     NOTE 'all' is also false in auto-commit mode where 'end of statement'
-     and 'real commit' mean the same event.
-   */
-   virtual int  commit(Session *, bool)
-   {
-     return 0;
-   }
-
-   virtual int  rollback(Session *, bool)
-   {
-     return 0;
-   }
-
-   virtual int  prepare(Session *, bool) { return 0; }
-   virtual int  recover(XID *, uint32_t) { return 0; }
-   virtual int  commit_by_xid(XID *) { return 0; }
-   virtual int  rollback_by_xid(XID *) { return 0; }
-   virtual handler *create(TABLE_SHARE *, MEM_ROOT *)= 0;
-   /* args: path */
-   virtual void drop_database(char*) { }
-   virtual int start_consistent_snapshot(Session *) { return 0; }
-   virtual bool flush_logs() { return false; }
-   virtual bool show_status(Session *, stat_print_fn *, enum ha_stat_type)
-   {
-     return false;
-   }
-
-   /* args: current_session, tables, cond */
-   virtual int fill_files_table(Session *, TableList *,
-                                Item *) { return 0; }
-   virtual int release_temporary_latches(Session *) { return false; }
-
-   /* args: current_session, db, name */
-   virtual int table_exists_in_engine(Session*, const char *, const char *);
+  bool is_enabled() const
+  {
+    return (state == SHOW_OPTION_YES);
+  }
+
+  std::string get_name() { return name; }
+
+  /*
+    StorageEngine methods:
+
+    close_connection is only called if
+    session->ha_data[xxx_engine.slot] is non-zero, so even if you don't need
+    this storage area - set it to something, so that MySQL would know
+    this storage engine was accessed in this connection
+  */
+  virtual int close_connection(Session  *)
+  {
+    return 0;
+  }
+  /*
+    The void * points to an uninitialized storage area of requested size
+    (see savepoint_offset description)
+  */
+  virtual int savepoint_set(Session *, void *)
+  {
+    return 0;
+  }
+
+  /*
+    The void * points to a storage area, that was earlier passed
+    to the savepoint_set call
+  */
+  virtual int savepoint_rollback(Session *, void *)
+  {
+    return 0;
+  }
+
+  virtual int savepoint_release(Session *, void *)
+  {
+    return 0;
+  }
+
+  /*
+    'all' is true if it's a real commit, that makes persistent changes
+    'all' is false if it's not in fact a commit but an end of the
+    statement that is part of the transaction.
+    NOTE 'all' is also false in auto-commit mode where 'end of statement'
+    and 'real commit' mean the same event.
+  */
+  virtual int  commit(Session *, bool)
+  {
+    return 0;
+  }
+
+  virtual int  rollback(Session *, bool)
+  {
+    return 0;
+  }
+
+  virtual int  prepare(Session *, bool) { return 0; }
+  virtual int  recover(XID *, uint32_t) { return 0; }
+  virtual int  commit_by_xid(XID *) { return 0; }
+  virtual int  rollback_by_xid(XID *) { return 0; }
+  virtual handler *create(TABLE_SHARE *, MEM_ROOT *)= 0;
+  /* args: path */
+  virtual void drop_database(char*) { }
+  virtual int start_consistent_snapshot(Session *) { return 0; }
+  virtual bool flush_logs() { return false; }
+  virtual bool show_status(Session *, stat_print_fn *, enum ha_stat_type)
+  {
+    return false;
+  }
+
+  /* args: current_session, tables, cond */
+  virtual int fill_files_table(Session *, TableList *,
+                               Item *) { return 0; }
+  virtual int release_temporary_latches(Session *) { return false; }
+
+  /* args: current_session, db, name */
+  virtual int table_exists_in_engine(Session*, const char *, const char *);
 };
 
 

